@@ -15,6 +15,7 @@ function searchPressed(key) {
 //init search
 function initSearch() {
     var value = $('#searchinput').val();
+    var searchService = $('#selectSearchService').val();
 
     if ((value.length < 100) && (value.length > 0)) {
         showLoading(true);
@@ -28,34 +29,47 @@ function initSearch() {
         delete customTracklists['trackresultscache'];
         $("#searchresults").hide();
 
-        mopidy.getUriSchemes().then(function (schemes) {
-            var query = {},
-                uris = [];
+        if (searchService != 'all') {
+            mopidy.library.search({any:[value]}, [searchService + ':']).then(processSearchResults, console.error);
+        } else {
+            mopidy.getUriSchemes().then(function (schemes) {
+                var query = {},
+                    uris = [];
 
-            var regexp = $.map(schemes, function (scheme) {
-                return '^' + scheme + ':';
-            }).join('|');
+                var regexp = $.map(schemes, function (scheme) {
+                    return '^' + scheme + ':';
+                }).join('|');
 
-            var match = value.match(regexp);
-            if (match) {
-                var scheme = match[0];
-                query = {uri: [value]};
-                uris = [scheme];
-            } else {
-                query = {any: [value]};
-            }
-
-            mopidy.library.search(query, uris).then(processSearchResults, console.error);
-            // console.log('search sent', value);
-        });
+                var match = value.match(regexp);
+                if (match) {
+                    var scheme = match[0];
+                    query = {uri: [value]};
+                    uris = [scheme];
+                } else {
+                    query = {any: [value]};
+                }
+                mopidy.library.search(query, uris).then(processSearchResults, console.error);
+            });
+        }
     }
 }
 
 /********************************************************
  * process results of a search
  *********************************************************/
+
+//# speed clone http://jsperf.com/cloning-an-object/2
+function clone(obj) {
+    var target = {};
+    for (var i in obj) {
+        if (obj.hasOwnProperty(i)) {
+            target[i] = obj[i];
+        }
+    }
+    return target;
+}
+
 function processSearchResults(resultArr) {
-//    console.log('srch', resultArr);
     $(SEARCH_TRACK_TABLE).empty();
     $(SEARCH_ARTIST_TABLE).empty();
     $(SEARCH_ALBUM_TABLE).empty();
@@ -63,10 +77,9 @@ function processSearchResults(resultArr) {
     // Merge results from different backends.
     // TODO  should of coures have multiple tables
     var results = {'tracks': [], 'artists': [], 'albums': []};
-    var emptyResult = true;
-
-
-    for (var i = 0; i < resultArr.length; ++i) {
+    var j, emptyResult = true;
+    
+/*    for (var i = 0; i < resultArr.length; ++i) {
         for (var prop in results) {
             if (resultArr[i][prop] && resultArr[i][prop].length) {
                 results[prop] = results[prop].concat(resultArr[i][prop]);
@@ -74,6 +87,31 @@ function processSearchResults(resultArr) {
             }
         }
     }
+*/
+    for (var i = 0; i < resultArr.length; i++) {
+        if (resultArr[i].tracks) {
+            for (j = 0; j < resultArr[i].tracks.length; j++) {
+                results.tracks.push(resultArr[i].tracks[j]);
+                emptyResult = false;
+            }
+        }
+        if (resultArr[i].artists) {
+            for (j = 0; j < resultArr[i].artists.length; j++) {
+                results.artists.push(resultArr[i].artists[j]);
+                emptyResult = false;
+            }
+        }
+        if (resultArr[i].albums) {
+            for (j = 0; j < resultArr[i].albums.length; j++) {
+                results.albums.push(resultArr[i].albums[j]);
+                emptyResult = false;
+            }
+        }
+    }
+
+//    console.log(resultArr, results);
+
+
 
     customTracklists['trackresultscache'] = results.tracks;
 
@@ -123,7 +161,7 @@ function processSearchResults(resultArr) {
     child = '';
     pattern = '<li><a href="#" onclick="return showAlbum(this.id)" id="{albumId}">';
     pattern += '<h5 data-role="heading"><i class="{class}"></i> {albumName}</h5>';
-    pattern += '<p data-role="desc">{artistName} ({albumYear})</p>';
+    pattern += '<p data-role="desc">{artistName}</p>';
     pattern += '</a></li>';
 
     for (var i = 0; i < results.albums.length; i++) {
@@ -134,13 +172,16 @@ function processSearchResults(resultArr) {
             'albumYear': results.albums[i].date,
             'class': getMediaClass(results.albums[i].uri)
         };
-
-        //console.log(i, results.albums[i].artists.length);
         if (results.albums[i].artists) {
             for (var j = 0; j < results.albums[i].artists.length; j++) {
-                tokens.artistName += results.albums[i].artists[j].name + ' ';
+                if (results.albums[i].artists[j].name) {
+                    tokens.artistName += results.albums[i].artists[j].name + ' ';
+                }
             }
         }
+        if (tokens.albumYear) {
+            tokens.artistName += '(' + tokens.albumYear + ')';
+        }
         // Add 'Show all' item after a certain number of hits.
         if (i == 4 && results.albums.length > 5) {
             child += theme(showMorePattern, {'count': results.albums.length - i});
@@ -150,7 +191,6 @@ function processSearchResults(resultArr) {
         child += theme(pattern, tokens);
     }
     // Inject list items, refresh listview and hide superfluous items.
-//    console.log(child, results.albums.length);
     $(SEARCH_ALBUM_TABLE).html(child).listview('refresh').find('.overflow').hide();
 
     $('#expandsearch').show();
@@ -199,7 +239,11 @@ function getCurrentPlaylist() {
 function togglePlaylists() {
     if ($(window).width() <= 960) {
         $('#playlisttracksdiv').toggle();
-        $('#playlistslistdiv').toggle();
+        //Hide other div
+        ($('#playlisttracksdiv').is(":visible")) ? $('#playlistslistdiv').hide() : $('#playlistslistdiv').show();
+    } else {
+        $('#playlisttracksdiv').show();
+        $('#playlistslistdiv').show();
     }
     return true;
 }
@@ -214,7 +258,7 @@ function showTracklist(uri) {
     } else {
         showLoading(true);
     }
-
+    updatePlayIcons(uri);
     $('#playlistslist li a').each(function() {
         $(this).removeClass("playlistactive");
         if (this.id == uri) {
@@ -223,6 +267,7 @@ function showTracklist(uri) {
     });
 //    scrollToTracklist();
     //lookup recent tracklist
+
     mopidy.playlists.lookup(uri).then(processGetTracklist, console.error);
     return false;
 }
@@ -232,6 +277,7 @@ function showTracklist(uri) {
  */
 
 function showArtist(nwuri) {
+    $('#popupQueue').popup('close');
     $('#popupTracks').popup('close');
     $('#controlsmodal').popup('close');
     $(ARTIST_TABLE).empty();
@@ -240,7 +286,10 @@ function showArtist(nwuri) {
 //TODO cache
     $('#h_artistname').html('');
     showLoading(true);
-    mopidy.library.lookup(nwuri).then(processArtistResults, console.error);
+    mopidy.library.lookup(nwuri).then(function(resultArr) {
+        resultArr.uri = nwuri;
+        processArtistResults(resultArr);
+    }, console.error);
     switchContent('artists', nwuri);
     scrollToTop();
     setSongInfo();
@@ -248,12 +297,13 @@ function showArtist(nwuri) {
 }
 
 function showAlbum(uri) {
+    $('#popupQueue').popup('close');
     $('#popupTracks').popup('close');
     $('#controlsmodal').popup('close');
     $(ALBUM_TABLE).empty();
     //fill from cache
     var pl = getTracksFromUri(uri);
-    if (pl) {
+    if (pl.length>0) {
         albumTracksToTable(pl, ALBUM_TABLE, uri);
         var albumname = getAlbum(pl);
         var artistname = getArtist(pl);
@@ -262,13 +312,19 @@ function showAlbum(uri) {
         $('#coverpopupalbumname').html(albumname);
         $('#coverpopupartist').html(artistname);
         showLoading(false);
-        getCover(artistname, albumname, '#albumviewcover, #coverpopupimage', 'extralarge');
-        mopidy.library.lookup(uri).then(processAlbumResults, console.error);
+        mopidy.library.lookup(uri).then(function(resultArr) {
+            resultArr.uri = uri;
+            processAlbumResults(resultArr);
+        }, console.error);
+//        getCover(pl, '#albumviewcover, #coverpopupimage', 'extralarge');
     } else {
         showLoading(true);
         $('#h_albumname').html('');
         $('#h_albumartist').html('');
-        mopidy.library.lookup(uri).then(processAlbumResults, console.error);
+        mopidy.library.lookup(uri).then(function(resultArr) {
+            resultArr.uri = uri;
+            processAlbumResults(resultArr);
+        }, console.error);
     }
     //show page
     switchContent('albums', uri);
@@ -276,3 +332,21 @@ function showAlbum(uri) {
     setSongInfo();
     return false;
 }
+
+function getSearchSchemes() {
+    mopidy.getUriSchemes().then(
+        function(schemesArray) {
+            var humanIndex;
+            $("#selectSearchService").children().remove().end();
+            $("#selectSearchService").append(new Option('All services', 'all'));
+            for (var i = 0; i < schemesArray.length; i++) {
+                for (var j = 0; j < uriHumanList.length; j++) {
+                    if (uriHumanList[j][0] == schemesArray[i].toLowerCase() ) {
+                        $("#selectSearchService").append(new Option(uriHumanList[j][1], schemesArray[i]));
+                    }
+                }
+            }
+            $("#selectSearchService").selectmenu( "refresh", true );
+        }, console.error
+    );
+}
